@@ -54,6 +54,9 @@ class mDastBase:
     def get_users(self):
         return requests.get(f'{self.url}/organizations/{self.current_context["company"]}/users', headers=self.headers)
 
+    def get_users_by_org(self, org_id):
+        return requests.get(f'{self.url}/organizations/{org_id}/users', headers=self.headers)
+
     def get_user_info(self, user_id):
         return requests.get(f'{self.url}/users/{user_id}/', headers=self.headers)
 
@@ -65,6 +68,17 @@ class mDastBase:
         }
         return requests.post(f'{self.url}/organizations/{org_id}/users/', headers=self.headers, data=json.dumps(data))
 
+    def create_user_by_superadmin(self, user_id, username, org_id, is_admin, is_active, position, change_pass):
+        data = {
+            'username': username,
+            'is_admin': is_admin,
+            'is_active': is_active,
+            'position': position,
+            'change_pass': change_pass,
+            'org_id': org_id
+        }
+        return requests.put(f'{self.url}/users/{user_id}/', headers=self.headers, data=json.dumps(data))
+
     def delete_user(self, user_id):
         return requests.delete(f'{self.url}/users/{user_id}/', headers=self.headers)
 
@@ -77,6 +91,16 @@ class mDastBase:
         }
         return requests.patch(f'{self.url}/users/{user_id}/', headers=self.headers, data=json.dumps(data))
 
+    def patch_user(self, user_id, username, is_admin, is_active, position, change_pass):
+        data = {
+            'username': username,
+            'is_admin': is_admin,
+            'is_active': is_active,
+            'position': position,
+            'change_pass': change_pass
+        }
+        return requests.patch(f'{self.url}/users/{user_id}/', headers=self.headers, data=json.dumps(data))
+
     def change_user_organisation(self, user_data, new_org_id):
         data = {
             'username': user_data['username'],
